@@ -202,12 +202,6 @@ function virtualenvwrapper_run_hook {
 
     hook_script="$(virtualenvwrapper_tempfile ${1}-hook)" || return 1
 
-    if [ -z "$VIRTUALENVWRAPPER_LOG_DIR" ]
-    then
-        echo "ERROR: VIRTUALENVWRAPPER_LOG_DIR is not set." 1>&2
-        command \rm -f "$hook_script"
-        return 1
-    fi
     "$VIRTUALENVWRAPPER_PYTHON" -c 'from virtualenvwrapper.hook_loader import main; main()' $HOOK_VERBOSE_OPTION --script "$hook_script" "$@"
     result=$?
 
@@ -286,12 +280,6 @@ function virtualenvwrapper_initialize {
         export VIRTUALENVWRAPPER_HOOK_DIR="$WORKON_HOME"
     fi
 
-    # Set the location of the hook script logs
-    if [ "$VIRTUALENVWRAPPER_LOG_DIR" = "" ]
-    then
-        export VIRTUALENVWRAPPER_LOG_DIR="$WORKON_HOME"
-    fi
-
     virtualenvwrapper_run_hook "initialize"
 
     virtualenvwrapper_setup_tab_completion
@@ -619,11 +607,51 @@ function showvirtualenv {
     echo
 }
 
+# Show help for workon
+function workon_help {
+    echo "Usage: workon env_name"
+    echo ""
+    echo "           Deactivate any currently activated virtualenv"
+    echo "           and activate the named environment, triggering"
+    echo "           any hooks in the process."
+    echo ""
+    echo "       workon"
+    echo ""
+    echo "           Print a list of available environments."
+    echo "           (See also lsvirtualenv -b)"
+    echo ""
+    echo "       workon (-h|--help)"
+    echo ""
+    echo "           Show this help message."
+    echo ""
+}
+
 # List or change working virtual environments
 #
 # Usage: workon [environment_name]
 #
 function workon {
+    in_args=( "$@" )
+
+    if [ -n "$ZSH_VERSION" ]
+    then
+        i=1
+        tst="-le"
+    else
+        i=0
+        tst="-lt"
+    fi
+    while [ $i $tst $# ]
+    do
+        a="${in_args[$i]}"
+        case "$a" in
+            -h|--help)
+                workon_help;
+                return 0;;
+        esac
+        i=$(( $i + 1 ))
+    done
+
     typeset env_name="$1"
     if [ "$env_name" = "" ]
     then
@@ -972,9 +1000,8 @@ function mkproject {
     while [ $i $tst $# ]
     do
         a="${in_args[$i]}"
-        # echo "arg $i : $a"
         case "$a" in
-            -h)
+            -h|--help)
                 mkproject_help;
                 return;;
             -t)
